Crate test_fork_macros

Crate test_fork_macros 

The procedural macro powering test-fork.

Attribute Macros

fork
A procedural macro for running a test or benchmark in a separate process.
test
A procedural macro for running a test in a separate process.